@@ -278,7 +278,7 @@ peony_file_management_properties_dialog_response_cb (GtkDialog *parent,
             section = "gospeony-61";
             break;
         }
-        preferences_show_help (GTK_WINDOW (parent), "ukui-user-guide", section);
+        preferences_show_help (GTK_WINDOW (parent), "ubuntu-kylin-help", section);
     }
     else if (response_id == GTK_RESPONSE_CLOSE)
     {
